@@ -4,7 +4,7 @@ use 5.012;
 use Encode();
 use Time::HiRes();
 
-our $VERSION = '1.0.1';
+our $VERSION = '1.1.0';
 
 =head1 NAME
 
@@ -89,7 +89,7 @@ Also it contains several C++ classes.
     $result = merge($dest, $source, $flags);
     $is_equal = compare($hash1, $hash2);
     $is_equal = compare($array1, $array2);
-    $cloned = clone($data);
+    $cloned = lclone($data);
     $cloned = fclone($data);
     $crypted = crypt_xor($data, $key);
     $val = string_hash($str);
@@ -256,33 +256,38 @@ And so on.
 However there is one difference: if $dest and $source are primitive scalars, instead of creating an alias, the $source variable
 is copied to $dest (or new result). If MERGE_COPY_SOURCE is disabled, copying is not deep, like $dest = $source.
 
-=head4 clone ($source)
+=head4 lclone ($source)
 
-Makes a deep copy of $source and returns it.
+Light clone: makes a deep copy of $source and returns it.
 
 Does not handle cross-references: references to the same data will be different references.
-If cycled reference presents in $source, it will croak.
+If a cycled reference is present in $source, it will croak.
 
 Handles CODEREFs and IOREFs, but doesn't clone it, just copies pointer to the same CODE and IO into new reference. All other
 data types are cloned normally.
 
-If clone encounters a blessed object and it has 'CLONE' method, the return value of this method is used instead of a default behaviour.
-You can call clone($self) again from 'CLONE' callback if you need to, for example to prevent cloning some of your properties:
+If C<clone> encounters a blessed object and it has a C<HOOK_CLONE> method, the return value of this method is used instead of a
+default behaviour. You can call C<[lf]clone($self)> again from C<HOOK_CLONE> if you need to, for example to prevent cloning some of
+your properties:
 
-    sub CLONE {
+    sub HOOK_CLONE {
         my $self = shift;
         my $tmp = delete local $self->{big_obj_backref};
-        my $ret = clone($self);
+        my $ret = lclone($self);
         $ret->{big_obj_backref} = $tmp;
         return $ret;
     }
 
-In this case second 'clone' call won't call CLONE callback on $self and will clone $self in a standart manner.
+In this case second C<lclone()> call won't call C<HOOK_CLONE> again and will clone $self in a standart manner.
 
 =head4 fclone ($source)
 
-Same as 'clone' but handles cross-references: references to the same data will be the same references.
-If cycled reference presents in $source, it will remain cycled in cloned data.
+Full clone: same as C<lclone()> but handles cross-references: references to the same data will be the same references.
+If a cycled reference is present in $source, it will remain cycled in cloned data.
+
+=head4 clone ($source, [$with_cross_checks])
+
+If C<$with_cross_checks> is false or omitted, behaves like C<lclone()>, otherwise like C<fclone()>
 
 =head4 compare ($data1, $data2)
 
